﻿import es, popuplib, gamethread, cfglib, time

info = es.AddonInfo()
info.name = "Vote Mute Players"
info.basename = "absolute_votemute"
info.version = 1.0
info.author = "Absolute"
info.url = "http://addons.eventscripts.com/addons/view/%s"%info.basename
info.description = "Allows players to start votemutes against other players, also remutes them if they rejoin"

es.ServerVar(info.basename, info.version, info.description + " made by " + info.author).makepublic()


config = cfglib.AddonCFG(es.getAddonPath(info.basename) + '/' + info.basename + '.cfg')
config.text('%s by %s , Version: %s'% (info.basename,info.author,info.version))
config.text(info.description)
config.text('Visit %s for updates' % info.url)
config.text('Settings:')
config.text('\n')

mute_command = config.cvar('mute_command', "sm_mute $name", 'The command used to PERMANENTLY mute players ($name stands for the steamid of the player)')
unmute_command = config.cvar('unmute_command', "sm_unmute $name", 'The command used to unmute players ($name stands for the steamid of the player)')
votemute_remute = config.cvar('votemute_remute', 1, 'If people who rejoin should get muted again')
votemute_percentage = config.cvar('votemute_percentage', 60, 'If this much percentage of all players muted someone then he will get muted')
votemute_minimum = config.cvar('votemute_minimum', 2, 'It atleast needs this much players to mute someone')
votemute_time = config.cvar('votemute_time', 360, 'The time the player gets muted (in seconds)')
database_time = config.cvar('database_time', 180, 'How long votes should stay in the database (in seconds) [This means if they leave, wait 180 seconds and rejoin then their votes needed to get muted are reset]')
votemute_immunes = config.cvar('votemute_immunes', "STEAM_0:1:1234567,STEAM_0:0:1", 'These steamids arent mute-able')


config.write()
config.execute()

mute_dict = {}
vote_list = {}



def mute(steamid,plyname):
    if str(mute_command).startswith("sm_mute"):
        # the problem with sm_mute is that it needs "#steamid"
        cmd = str(mute_command).replace("$name",'"#' + steamid + '"')
    else:
        cmd = str(mute_command).replace("$name",steamid)
    es.msg("#multi","#greenMuted #default%s #greenfor %i seconds" % (plyname,mute_dict[steamid]["muteend"]-time.time()))
    gamethread.delayedname(mute_dict[steamid]["muteend"]-time.time()+1,"unmute " + steamid,removemute,steamid)
    es.server.queuecmd(cmd)
    
def removemute(steamid):
    if not stillmute(steamid):
        if str(unmute_command).startswith("sm_mute"):
            cmd = str(unmute_command).replace("$name",'"#' + steamid + '"')
        else:
            cmd = str(mute_command).replace("$name",steamid)
            
        es.server.queuecmd(cmd)
        
        removesteamid(steamid)
    else:
        gamethread.delayedname(time.time()-mute_dict[steamid]["muteend"]+1,"unmute " + steamid,removemute,steamid)


    
def player_activate(event_var):
    steamid = event_var['es_steamid']
    name = event_var['es_username']
    gamethread.cancelDelayed("remove " + steamid)
    if votemute_remute:
        if steamid in mute_dict:
            if stillmute(steamid):
                mute(steamid,name)
            else:
                del mute_dict[steamid]
            
def player_disconnect(event_var):
    userid = int(event_var["userid"])
    steamid = event_var["es_steamid"]
    if userid in vote_list:
        for plysteam in vote_list[userid]:
            if plysteam in mute_dict:
                if userid in mute_dict[plysteam]["votedplayers"]:
                    mute_dict[plysteam]["votedplayers"].remove(userid)
            
        del vote_list[userid]
        
    votecheck()
    gamethread.delayedname(database_time,"remove " + steamid, removesteamid,steamid)
    
def es_map_start(event_var):
    votecheck()
    
def removesteamid(steamid):
    if steamid in mute_dict:
        for userid in mute_dict[steamid]:
            if userid in vote_list:
                if steamid in vote_list[userid]:
                    vote_list[userid].remove(steamid)
        del mute_dict[steamid]
    gamethread.cancelDelayed("unmute " + steamid)
        
def stillmute(steamid):
    if "muteend" in mute_dict[steamid]:
        if mute_dict[steamid]["muteend"]-time.time() >= 0:
            return True

    return False
            
def player_say(event_var):
    text = event_var["text"]
    userid = int(event_var["userid"])
    if text == "votemute" or text == "vm":
        votepopup = popuplib.easymenu("votelist",None,voteselect)
        votepopup.settitle("Choose a player to mute")
        neededvotes = getneededvotes()
        for x in es.getUseridList():
            if x == userid:
                continue
            plysteam = es.getplayersteamid(x)
            if plysteam in str(votemute_immunes).split(","):
                continue
            if plysteam not in mute_dict:
                votes = 0 
            else:
                if stillmute(plysteam):
                    votepopup.addoption(-1,"%s [MUTED]" % es.getplayername(x))
                    continue
                votes = len(mute_dict[plysteam]["votedplayers"])
            votepopup.addoption(x,"%s [%s/%s votes]" % (es.getplayername(x),votes,neededvotes))
        votepopup.send(userid)


def votecheck():
    neededvotes = getneededvotes()
    for plysteam in mute_dict:
        if len(mute_dict[plysteam]["votedplayers"]) >= int(neededvotes):
            mute(plysteam,es.getplayername(es.getuserid(plysteam)))
            
def getneededvotes():
    neededvotes = int((es.getplayercount()-1)*(int(votemute_percentage)/100.0))
    if neededvotes < int(votemute_minimum):
        neededvotes = int(votemute_minimum)
    return neededvotes
        
def voteselect(userid,choice,popup):
    if choice == -1:
        return
    plysteam = es.getplayersteamid(choice)
    plyname = es.getplayername(choice)
    
    if userid not in vote_list:
        vote_list[userid] = []
    if plysteam not in vote_list[userid]:
        vote_list[userid].append(plysteam)
    
    if plysteam not in mute_dict:
        mute_dict[plysteam] = {}
        mute_dict[plysteam]["votedplayers"] = []
    if userid not in mute_dict[plysteam]["votedplayers"]:
        mute_dict[plysteam]["votedplayers"].append(userid)
        neededvotes = getneededvotes()
        
        if len(mute_dict[plysteam]["votedplayers"]) >= int(neededvotes):
            mute_dict[plysteam]["muteend"] = time.time() + int(votemute_time) + 1
            mute_dict[plysteam]["votedplayers"] = []
            mute(plysteam,plyname)
        else:
            es.msg("#multi","#green%s wants to mute #default%s#green, %s more votes required, type #lightgreenvotemute#green to join in" % (es.getplayername(userid),plyname,neededvotes-len(mute_dict[plysteam]["votedplayers"])))
    else:
        es.tell(userid,"#multi","#greenYou have already voted to mute #default%s" % plyname )
